//! # Comunic administrator
//!
//! @author Pierre Hubert

use webauthn_rs::proto::Credential;

#[derive(Copy, Clone, Eq, PartialEq, Debug, Hash)]
pub struct AdminID(u64);

impl AdminID {
    pub fn new(id: u64) -> Self {
        Self(id)
    }

    pub fn id(&self) -> u64 {
        self.0
    }

    pub fn id_str(&self) -> String {
        format!("{}", self.0)
    }
}

pub struct NewAdmin {
    pub name: String,
    pub email: String,
}

pub struct AdminResetToken {
    pub token: String,
    pub expire: u64,
}

pub struct Admin {
    pub id: AdminID,
    pub time_create: u64,
    pub name: String,
    pub email: String,
    pub reset_token: Option<AdminResetToken>,
}

pub struct AdminKey {
    pub id: u64,
    pub admin_id: AdminID,
    pub name: String,
    pub key: Credential,
}

/// Admin access token
///
/// Used to store authentication of an admin
#[derive(Clone, Debug)]
pub struct AdminAccessToken {
    pub token: String,
    pub id: AdminID,
    pub last_refresh: u64,
}

/// New admin general settings
pub struct NewAdminGeneralSettings {
    pub id: AdminID,
    pub name: String,
    pub email: String,
}